BCML Help

Skip to content

# Welcome to BCML Help

Hello, thanks for downloading BCML: Breath of the Wild Cross-Platform Mod Loader. Modding BOTW is far from a simple task, so I hope this little bundle of help pages will be of some use as you seek your perfect mod setup. For the most common issues and problems, head straight to the Troubleshooting page. If you're looking for basic guidance on using BCML, stick around here.

The main BCML UI

## BCML 101

Here's how BCML works:

- You install mods into BCML. Click the floating action button on the Mods tab to open the install dialog and go from there.
- Use the sort handles if you need to edit load order. Use the Remege button liberally when anything goes wrong.
- If you're a Cemu user, all installed mods should take effect next time you run the game.
- You do not have to launch BOTW from BCML. BCML installs its merged mods as a single graphic pack into your Cemu `graphicPacks` folder, and it will work the same as any other graphic pack mod.
- If you're a console user, use the Export button to generate a merged pack pack to install with SDCafiine or Atmosphere or what-have-you.